@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: accessManager.php 2991 2010-03-30 12:43:38Z fishbone $
+ * @version    SVN: $Id: accessManager.php 3692 2010-10-11 06:57:09Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -179,6 +179,7 @@ class AccessManager extends Core
 			$userId = $userInfo->userId;
 		}
 		$cookieVal	= isset($this->_clientId) ? $this->_clientId : '';			// アクセス管理用クッキー
+		$session	= session_id();				// セッションID
 		$ip			= $gRequestManager->trimServerValueOf('REMOTE_ADDR');		// クライアントIP
 		$method		= $gRequestManager->trimServerValueOf('REQUEST_METHOD');	// アクセスメソッド
 		$uri		= $gRequestManager->trimServerValueOf('REQUEST_URI');
@@ -197,7 +198,7 @@ class AccessManager extends Core
 		$path = $gEnvManager->getAccessPath();
 		
 		// アクセスログのシリアルNoを保存
-		$this->_accessLogSerialNo = $this->db->accessLog($userId, $cookieVal, $ip, $method, $uri, $referer, $request, $agent, $language, $path);
+		$this->_accessLogSerialNo = $this->db->accessLog($userId, $cookieVal, $session, $ip, $method, $uri, $referer, $request, $agent, $language, $path);
 	}
 	
 	/**
