@@ -8,16 +8,20 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: analyzeManager.php 3542 2010-08-28 04:03:06Z fishbone $
+ * @version    SVN: $Id: analyzeManager.php 4077 2011-04-19 15:38:57Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
+require_once(M3_SYSTEM_INCLUDE_PATH . '/db/analyticsDb.php');
 
 class AnalyzeManager extends Core
 {
 	private $db;						// DBオブジェクト
+	private $analyticsDb;
+	const CF_LAST_DATE_CALC_PV	= 'last_date_calc_pv';	// ページビュー集計の最終更新日
+	const MAX_CALC_DAYS = 30;					// 最大集計日数
 	
 	/**
 	 * コンストラクタ
@@ -29,6 +33,7 @@ class AnalyzeManager extends Core
 		
 		// システムDBオブジェクト取得
 		$this->db = $this->gInstance->getSytemDbObject();
+		$this->analyticsDb = new analyticsDb();
 	}
 	/**
 	 * コンテンツのビューカウントを更新
@@ -227,5 +232,68 @@ class AnalyzeManager extends Core
 		}	
 		return 'xx';
 	}
+	/**
+	 * アクセスログからアクセス解析用のデータを作成
+	 *
+	 * @param array  	$message	エラーメッセージ
+	 * @param int		$maxDay		最大集計日数
+	 * @return bool					true=正常終了、false=異常終了
+	 */
+	function updateAnalyticsData(&$message = null, $maxDay = self::MAX_CALC_DAYS)
+	{
+		$ret = $this->analyticsDb->getOldAccessLog($row);
+		if ($ret){		// 集計対象のデータが存在するとき
+			$startDate = date("Y/m/d", strtotime($row['al_dt']));
+			$lastDate = $this->analyticsDb->getStatus(self::CF_LAST_DATE_CALC_PV);
+
+			// 集計開始日を求める
+			if (!empty($lastDate)){
+				$startDate = date("Y/m/d", strtotime("$lastDate 1 day"));		// 翌日
+			}
+			// 集計終了日を求める
+			$endDate = date("Y/m/d", strtotime("-1 day"));	// 前日
+			$endTime = strtotime($endDate);
+		
+			// 集計処理を行う
+			$dayCount = 0;		// 集計日数
+			$date = $startDate;
+			while (true){
+				if (strtotime($date) > $endTime){
+					if (!is_null($message)) $message[] = '集計完了しました';
+					break;
+				}
+				// トランザクションスタート
+				$this->analyticsDb->startTransaction();
+
+				$ret = $this->analyticsDb->calcDatePv($date);
+				
+				// 集計日付を更新
+				if ($ret) $ret = $this->analyticsDb->updateStatus(self::CF_LAST_DATE_CALC_PV, $date);
+				
+				// トランザクション終了
+				$this->analyticsDb->endTransaction();
+
+				// エラーの場合は終了
+				if (!$ret){
+					if (!is_null($message)) $message[] = 'エラーが発生しました';
+					break;
+				}
+				
+				// 集計日数を更新
+				$dayCount++;
+				if ($dayCount >= $maxDay){
+					if (!is_null($message)) $message[] = $maxDay . '日分の集計完了しました';
+					break;
+				}
+				
+				$date = date("Y/m/d", strtotime("$date 1 day"));
+			}
+		} else {				// 集計データがないとき
+			if (!is_null($message)) $message[] = '集計対象のアクセスログがありません';
+			
+			$ret = true;		// 正常終了
+		}
+		return $ret;
+	}
 }
 ?>
