@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: systemManager.php 3923 2011-01-05 07:07:02Z fishbone $
+ * @version    SVN: $Id: systemManager.php 4096 2011-05-03 04:51:31Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');		// Magic3コアクラス
@@ -21,6 +21,7 @@ class SystemManager extends Core
 {
 	private $_systemConfigArray = array();			// システム定義値
 	private $_siteDefArray = array();			// サイト定義値
+	private $defaultAdminTemplateId;				// 管理画面用テンプレートID
 	private $defaultTemplateId;						// PC用テンプレートID
 	private $defaultMobileTemplateId;				// 携帯用テンプレートID
 	private $defaultSmartphoneTemplateId;				// スマートフォン用テンプレートID
@@ -51,6 +52,7 @@ class SystemManager extends Core
 	const CF_DEFAULT_TEMPLATE_SMARTPHONE	= 'smartphone_default_template';	// システム定義値取得用キー(スマートフォン用デフォルトテンプレート)
 	const CF_ADMIN_DEFAULT_THEME = 'admin_default_theme';		// 管理画面用jQueryUIテーマ
 	const CF_ACCEPT_LANGUAGE	= 'accept_language';	// アクセス可能言語
+	const CF_ADMIN_DEFAULT_TEMPLATE = 'admin_default_template';		// 管理用デフォルトテンプレート
 	const DEFAULT_PAGE_CACHE_LIFETIME = 1440;		// デフォルトの画面キャッシュの更新時間(分)。1日ごと。
 	
 	/**
@@ -65,6 +67,7 @@ class SystemManager extends Core
 		$this->db = $this->gInstance->getSytemDbObject();
 		
 		// 初期値を設定
+		$this->defaultAdminTemplateId = '';				// 管理画面用テンプレートID
 		$this->defaultTemplateId = '';						// PC用テンプレートID
 		$this->defaultMobileTemplateId = '';				// 携帯用テンプレートID
 		$this->defaultSmartphoneTemplateId = '';			// スマートフォン用テンプレートID
@@ -131,6 +134,7 @@ class SystemManager extends Core
 				$this->_systemConfigArray[$key] = $value;
 			}
 			// メンバー変数に再設定
+			$this->defaultAdminTemplateId	= $this->getSystemConfig(self::CF_ADMIN_DEFAULT_TEMPLATE);				// 管理画面用テンプレートID
 			$this->defaultTemplateId		= $this->getSystemConfig(self::CF_DEFAULT_TEMPLATE);	// PC用テンプレートID
 			$this->defaultMobileTemplateId	= $this->getSystemConfig(self::CF_DEFAULT_TEMPLATE_MOBILE);// 携帯用テンプレートID
 			$this->defaultSmartphoneTemplateId = $this->getSystemConfig(self::CF_DEFAULT_TEMPLATE_SMARTPHONE);		// スマートフォン用テンプレートID
@@ -271,6 +275,19 @@ class SystemManager extends Core
 		}
 		return $this->useTemplateIdInSession;
 	}
+	/**
+	 * 管理画面用のデフォルトのテンプレートIDを取得
+	 *
+	 * @param bool $reload	再取得するかどうか
+	 * @return string	デフォルトのテンプレートID
+	 */
+	function defaultAdminTemplateId($reload = false)
+	{
+		if ($reload){
+			$this->defaultAdminTemplateId		= $this->db->getSystemConfig(self::CF_ADMIN_DEFAULT_TEMPLATE);
+		}
+		return $this->defaultAdminTemplateId;
+	}
 	/**
 	 * デフォルトのテンプレートIDを取得
 	 *
