@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: update_widgets.sql 4049 2011-03-27 06:09:39Z fishbone $
+-- * @version    SVN: $Id: update_widgets.sql 4120 2011-05-07 13:32:44Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -35,6 +35,18 @@ DELETE FROM _widgets WHERE wd_id = 'admin_main';
 INSERT INTO _widgets
 (wd_id,        wd_name,      wd_admin, wd_author,      wd_copyright, wd_license, wd_official_level, wd_add_script_lib, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_install_dt, wd_create_dt) VALUES
 ('admin_main', '管理用画面', true,     'Naoki Hirata', 'Magic3.org', 'GPL',      10,                'pagedef=jquery-ui.tabs;pagedef_mobile=jquery-ui.tabs;pagedef_smartphone=jquery-ui.tabs;menudef=jquery.simpletree;analyzegraph=jquery.jqplot;adjustwidget=jquery-ui.tabs;', false,        false,       false,        true,          false, true, now(),now());
+DELETE FROM _widgets WHERE wd_id = 'admin/analytics';
+INSERT INTO _widgets
+(wd_id,             wd_name,            wd_admin, wd_author,      wd_copyright, wd_license, wd_official_level, wd_add_script_lib, wd_available, wd_editable, wd_has_admin, wd_initialized,  wd_install_dt, wd_create_dt) VALUES
+('admin/analytics', '管理用サイト解析', true,     'Naoki Hirata', 'Magic3.org', 'GPL',      10,                'jquery.jqplot', false,        false,       true, true,           now(),         now());
+DELETE FROM _widgets WHERE wd_id = 'admin/opelog';
+INSERT INTO _widgets
+(wd_id,             wd_name,            wd_admin, wd_author,      wd_copyright, wd_license, wd_official_level, wd_add_script_lib, wd_available, wd_editable, wd_has_admin, wd_initialized,  wd_install_dt, wd_create_dt) VALUES
+('admin/opelog', '管理用運用ログ表示', true,     'Naoki Hirata', 'Magic3.org', 'GPL',      10,                '', false,        false,       true, true,           now(),         now());
+DELETE FROM _widgets WHERE wd_id = 'admin/loginuser';
+INSERT INTO _widgets
+(wd_id,             wd_name,            wd_admin, wd_author,      wd_copyright, wd_license, wd_official_level, wd_add_script_lib, wd_available, wd_editable, wd_has_admin, wd_initialized,  wd_install_dt, wd_create_dt) VALUES
+('admin/loginuser', '管理用ログインユーザ情報', true,     'Naoki Hirata', 'Magic3.org', 'GPL',      10,                '', false,        false,       false, true,           now(),         now());
 
 -- ウィジェット情報(PC用)
 DELETE FROM _widgets WHERE wd_id = 'default_mainmenu';
@@ -44,12 +56,6 @@ DELETE FROM _widgets WHERE wd_id = 'default_menu';
 INSERT INTO _widgets
 (wd_id,                wd_name, wd_type,                      wd_version, wd_joomla_class, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_add_script_lib_a,                         wd_has_admin, wd_use_instance_def, wd_initialized, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
 ('default_menu', 'デフォルトメニュー', 'menu',         '1.0.0',    '_menu', 'Naoki Hirata', 'Magic3.org', 'GPL',      10,                '複数のメニューが作成できる1階層の新型デフォルトメニューです。サブメニューも管理できる共通のメニュー定義を使用します。ナビゲーションメニューの位置(画面上部)にある「user3」ポジションに配置するとナビゲーションメニューが表示できます。', '', 'jquery-ui.tabs', true,  true,              true, 2,          1, now(),         now());
-DELETE FROM _widgets WHERE wd_id = 'nav_menu';
-INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_launch_index, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt, wd_status) VALUES
-('nav_menu',   'ナビゲーションメニュー(廃止予定)',   'menu', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'ページのヘッダ下や、フッタ部に表示するメニュー。',           false,           false,       false,         true,        true,         false,               false,true,           0, 1, -1, now(), now(), -1);
-DELETE FROM _widgets WHERE wd_id = 'nav_menu_css';
-INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_launch_index, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt, wd_status) VALUES
-('nav_menu_css',   'ナビゲーションメニュー(CSS)(廃止予定)',   'menu', '1.0.0',  '',        '', 'Magic3.org', 'GPL', 10, 'ページのヘッダ下や、フッタ部に表示するメニュー。SPANタグにて表示。',           false,           false,       false,         true,        true,         false,               false,true,           0, 1, -1, now(), now(), -1);
 DELETE FROM _widgets WHERE wd_id = 'accordion_menu';
 INSERT INTO _widgets
 (wd_id,            wd_name, wd_type,                  wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_add_script_lib_a,                         wd_has_admin, wd_use_instance_def, wd_initialized, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
