@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainOpelogWidgetContainer.php 3897 2010-12-18 03:53:54Z fishbone $
+ * @version    SVN: $Id: admin_mainOpelogWidgetContainer.php 4116 2011-05-07 10:49:02Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -278,7 +278,8 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 				if ($i == $pageNo){
 					$link = '&nbsp;' . $i;
 				} else {
-					$link = '&nbsp;<a href="#" onclick="selpage(\'' . $i . '\');return false;">' . $i . '</a>';
+					//$link = '&nbsp;<a href="#" onclick="selpage(\'' . $i . '\');return false;">' . $i . '</a>';
+					$link = '&nbsp;<a href="?task=opelog&act=selpage&page=' . $i . '">' . $i . '</a>';
 				}
 				$pageLink .= $link;
 			}
