@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_calendar_boxWidgetContainer.php 3994 2011-02-13 13:46:39Z fishbone $
+ * @version    SVN: $Id: blog_calendar_boxWidgetContainer.php 4009 2011-02-22 09:39:39Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -104,7 +104,7 @@ class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 		$calendarData .= '<table id="blog_calendar">' . M3_NL;
 		$calendarData .= '<tr>' . M3_NL;
 		$calendarData .= '<th class="sun" style="background:none;">日</th>' . M3_NL;
-		$calendarData .= '<th class="*" style="background:none;">月</th>' . M3_NL;
+		$calendarData .= '<th style="background:none;">月</th>' . M3_NL;
 		$calendarData .= '<th style="background:none;">火</th>' . M3_NL;
 		$calendarData .= '<th style="background:none;">水</th>' . M3_NL;
 		$calendarData .= '<th style="background:none;">木</th>' . M3_NL;
