@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: wiki_mainDb.php 1141 2008-10-27 06:10:58Z fishbone $
+ * @version    SVN: $Id: wiki_mainDb.php 1161 2008-10-30 08:47:27Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -197,7 +197,8 @@ class wiki_mainDb extends BaseDb
 		$queryStr .=  'ORDER BY wc_history_index DESC ';
 		$ret = $this->selectRecord($queryStr, array($type, $name), $row);
 		if ($ret){
-			if (!$row['wc_deleted']){		// レコードが削除されていなければ削除
+			if ($row['wc_deleted']){// レコードが削除されているときは、新規追加とする
+			} else {		// レコードが削除されていなければ削除
 				// 古いレコードを削除
 				$queryStr  = 'UPDATE wiki_content ';
 				$queryStr .=   'SET wc_deleted = true, ';	// 削除
@@ -205,12 +206,13 @@ class wiki_mainDb extends BaseDb
 				$queryStr .=     'wc_update_dt = ? ';
 				$queryStr .=   'WHERE wc_serial = ?';
 				$this->execStatement($queryStr, array($userId, $now, $row['wc_serial']));
+				
+				$locked = $row['wc_locked'];		// ロック状態を引き継ぐ
+				// 更新日時を維持のときは更新日時取得
+				if ($keepTime) $contentNow = $row['wc_content_dt'];
 			}
+			// 履歴インデックス番号作成
 			$historyIndex = $row['wc_history_index'] + 1;
-			$locked = $row['wc_locked'];
-			
-			// 更新日時を維持のときは更新日時取得
-			if ($keepTime) $contentNow = $row['wc_content_dt'];
 		}
 
 		// 新規レコード追加
@@ -264,6 +266,87 @@ class wiki_mainDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	/**
+	 * ページを変更
+	 *
+	 * @param string $oldName		旧ページ名
+	 * @param string $newName		新ページ名
+	 * @param string  $type			ページタイプ
+	 * @return bool					true=成功、false=失敗
+	 */
+	public function renamePage($oldName, $newName, $type='')
+	{
+		global $gEnvManager;
+		
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+		
+		// トランザクションスタート
+		$this->startTransaction();
+		
+		// ##### 旧ページを取得 #####
+		$queryStr = 'SELECT * from wiki_content ';
+		$queryStr .=  'WHERE wc_type = ? ';
+		$queryStr .=    'AND wc_id = ? ';
+		$queryStr .=    'AND wc_deleted = false';
+		$ret = $this->selectRecord($queryStr, array($type, $oldName), $oldRow);
+		if (!$ret){
+			// トランザクション終了
+			$ret = $this->endTransaction();
+			return false;
+		}
+		
+		// ##### 新ページを作成 #####
+		$historyIndex = 0;		// 履歴番号
+		
+		// 前レコードの削除状態チェック
+		$queryStr = 'SELECT * FROM wiki_content ';
+		$queryStr .=  'WHERE wc_type = ? ';
+		$queryStr .=    'AND wc_id = ? ';
+		$queryStr .=  'ORDER BY wc_history_index DESC ';
+		$ret = $this->selectRecord($queryStr, array($type, $newName), $row);
+		if ($ret){
+			if ($row['wc_deleted']){// レコードが削除されているときは、新規追加とする
+			} else {		// レコードが削除されていなければ削除
+				// 古いレコードを削除
+				$queryStr  = 'UPDATE wiki_content ';
+				$queryStr .=   'SET wc_deleted = true, ';	// 削除
+				$queryStr .=     'wc_update_user_id = ?, ';
+				$queryStr .=     'wc_update_dt = ? ';
+				$queryStr .=   'WHERE wc_serial = ?';
+				$this->execStatement($queryStr, array($userId, $now, $row['wc_serial']));
+			}
+			// 履歴インデックス番号作成
+			$historyIndex = $row['wc_history_index'] + 1;
+		}
+
+		// 新規レコード追加
+		$queryStr = 'INSERT INTO wiki_content ';
+		$queryStr .=  '(wc_type, wc_id, wc_history_index, wc_data, wc_content_dt, wc_locked, wc_fore_serial, wc_create_user_id, wc_create_dt) ';
+		$queryStr .=  'VALUES ';
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$this->execStatement($queryStr, array($type, $newName, $historyIndex, $oldRow['wc_data'], 
+			$oldRow['wc_content_dt'], $oldRow['wc_locked'], $oldRow['wc_serial']/*引き継ぎシリアル番号*/, $userId, $now));
+		
+		// シリアル番号取得
+		$newSerial = 0;
+		$queryStr = 'SELECT MAX(wc_serial) AS ns FROM wiki_content ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret) $newSerial = $row['ns'];
+		
+		// 旧ページを削除
+		$queryStr  = 'UPDATE wiki_content ';
+		$queryStr .=   'SET wc_deleted = true, ';	// 削除
+		$queryStr .=     'wc_update_user_id = ?, ';
+		$queryStr .=     'wc_update_dt = ?, ';
+		$queryStr .=     'wc_next_serial = ? ';		// 引き継ぎシリアル番号
+		$queryStr .=   'WHERE wc_serial = ?';
+		$this->execStatement($queryStr, array($userId, $now, $newSerial, $oldRow['wc_serial']));
+		
+		// トランザクション終了
+		$ret = $this->endTransaction();
+		return $ret;
+	}
 	/**
 	 * Wikiページのロックの制御
 	 *
