@@ -1,6 +1,6 @@
 <?php
 // PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: en.lng.php 1162 2008-10-31 04:27:21Z fishbone $
+// $Id: en.lng.php 3474 2010-08-13 10:36:48Z fishbone $
 // Copyright (C)
 //   2002-2005 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
@@ -264,8 +264,8 @@ $_LANG['skin']['refer']     = 'Referer';	// Show list of referer
 $_LANG['skin']['reload']    = 'Reload';
 $_LANG['skin']['rename']    = 'Rename';	// Rename a page (and related)
 $_LANG['skin']['rss']       = 'RSS of recent changes';
-$_LANG['skin']['rss10']     = & $_LANG['skin']['rss'];
-$_LANG['skin']['rss20']     = & $_LANG['skin']['rss'];
+$_LANG['skin']['rss10']     = $_LANG['skin']['rss'];
+$_LANG['skin']['rss20']     = $_LANG['skin']['rss'];
 $_LANG['skin']['search']    = 'Search';
 $_LANG['skin']['top']       = 'Front page';	// Top page
 $_LANG['skin']['trackback'] = 'Trackback';	// Show list of trackback
